from .BackgroundRemoval import BackgroundRemoval
from .Codeformer import Codeformer
from .ESRGAN import ESRGAN
from .SD1_5 import SD1_5
from .SD2_1 import SD2_1
from .Kadinsky import Kadinsky
from .FaceSwap import FaceSwap
from .SAM import SAM
from .ControlNet import ControlNet
from .TinySD import TinySD
from .SDXL import SDXL
from .PortraitSD import PortraitSD
from .SmallSD import SmallSD
from .CyberRealistic import CyberRealistic
from .Paragon import Paragon
from .RealisticVision import RealisticVision
from .Reliberate import Reliberate
from .Revanimated import Revanimated
from .Colorful import Colorful
from .Cartoon import Cartoon
from .EdgeOfRealism import EdgeOfRealism
from .EpicRealism import EpicRealism
from .RPG import RPG
from .SciFi import SciFi
from .Samaritan import Samaritan
from .RCNZ import RCNZ
from .MajicMix import MajicMix
from .ManmaruMix import ManmaruMix
from .Juggernaut import Juggernaut
from .Icbinp import Icbinp
from .FruitFusion import FruitFusion
from .Flat2D import Flat2D
from .FantassifiedIcons import FantassifiedIcons
from .DeepSpaceDiffusion import DeepSpaceDiffusion
from .DreamShaper import DreamShaper
from .DvArch import DvArch
from .CuteRichStyle import CuteRichStyle
from .AllInOnePixel import AllInOnePixel
from .Mix526 import Mix526
from .SDOutpainting import SDOutpainting
from .Word2Img import Word2Img
from .QRGenerator import QRGenerator
